@@ -24,13 +24,15 @@ class Client(object):
         endpoint,
         token,
         workspaceId,
+        replaceLocalhostString=None
     ):
         self.workspace = cannerflow.workspace.Workspace(
             endpoint=endpoint,
             headers={
                 "Authorization": f"Bearer {token}"
             },
-            workspaceId=workspaceId
+            workspaceId=workspaceId,
+            replaceLocalhostString=replaceLocalhostString
         )
     def use_saved_query(self, title):
         query = self.workspace.saved_query.get(title)
