@@ -41,7 +41,7 @@ class File(object):
         return list(map(lambda x: x['absolutePath'], data))
     def _replace_localhost(self, url):
         if (self.replaceLocalhostString != None):
-            return url.replace('localhost', self.replaceLocalhostString)
+            return url.replace('localhost', self.replaceLocalhostString).replace('127.0.0.1', self.replaceLocalhostString)
         else:
             return url;
     def _get_download_signed_url(self, absolutePath):
